@@ -282,7 +282,7 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
                 raise KempTechApiException(code=status_code)
             return True
         except exceptions.RequestException as e:
-            raise KempTechApiException("Enable API failed because of: {}".format(
+            raise KempTechApiException(msg="Enable API failed because of: {}".format(
                 e.__class__.__name__), is_xml_msg=False)
 
     def stats(self):
